"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var sqliteModels = require("../../models/sqlite.models");
var helperObjects = require("../../helpers/objects");
var helperFunctions = require("../../helpers/functions");
var typeChecks = require("../../services/typeCheck.service");
/* Abstracts and implementables */
var Constraint = (function () {
    function Constraint(name, columns) {
        if (columns === void 0) { columns = []; }
        this.name = name;
        this.columns = columns;
    }
    Constraint.prototype.validate = function () {
        var summary = new helperObjects.Summary();
        if (this.name === null || helperFunctions.isNullOrWhitespace(this.name))
            summary.errorMessages.push("Name cannot be NULL or whitespace");
        if (!this.columns || !this.columns.length)
            summary.errorMessages.push("Constraints must reference at least one column");
        return summary;
    };
    return Constraint;
}());
exports.Constraint = Constraint;
/* Specific Constraints */
var PKConstraint = (function (_super) {
    __extends(PKConstraint, _super);
    function PKConstraint(name, columns, autoIncrement, order, onConflict) {
        if (columns === void 0) { columns = []; }
        if (autoIncrement === void 0) { autoIncrement = true; }
        if (order === void 0) { order = "asc"; }
        if (onConflict === void 0) { onConflict = sqliteModels.DefaultConstraintConflictResolution; }
        var _this = _super.call(this, name, columns) || this;
        _this.autoIncrement = autoIncrement;
        _this.order = order;
        _this.onConflict = onConflict;
        return _this;
    }
    PKConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (!typeChecks.isSqliteOrder(this.order))
            summary.errorMessages.push("Order must be 'asc' or 'desc'");
        if (!typeChecks.isSqliteConstraintConflictResolution(this.onConflict))
            summary.errorMessages.push("Invalid conflict resolution type");
        return summary;
    };
    return PKConstraint;
}(Constraint));
exports.PKConstraint = PKConstraint;
var FKConstraint = (function (_super) {
    __extends(FKConstraint, _super);
    function FKConstraint(name, columns, parentTable, parentColumn) {
        if (columns === void 0) { columns = []; }
        if (parentTable === void 0) { parentTable = null; }
        if (parentColumn === void 0) { parentColumn = null; }
        var _this = _super.call(this, name, columns) || this;
        _this.parentTable = parentTable;
        _this.parentColumn = parentColumn;
        return _this;
    }
    FKConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (helperFunctions.isNullOrWhitespace(this.parentColumn))
            summary.errorMessages.push("FKs must reference a parent column");
        if (helperFunctions.isNullOrWhitespace(this.parentTable))
            summary.errorMessages.push("FKs must reference a parent table");
        return summary;
    };
    return FKConstraint;
}(Constraint));
exports.FKConstraint = FKConstraint;
var NotNullConstraint = (function (_super) {
    __extends(NotNullConstraint, _super);
    function NotNullConstraint(name, columns, onConflict) {
        if (columns === void 0) { columns = []; }
        if (onConflict === void 0) { onConflict = sqliteModels.DefaultConstraintConflictResolution; }
        var _this = _super.call(this, name, columns) || this;
        _this.onConflict = onConflict;
        return _this;
    }
    NotNullConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (!typeChecks.isSqliteConstraintConflictResolution(this.onConflict))
            summary.errorMessages.push("Invalid conflict resolution type");
        return summary;
    };
    return NotNullConstraint;
}(Constraint));
exports.NotNullConstraint = NotNullConstraint;
var UniqueConstraint = (function (_super) {
    __extends(UniqueConstraint, _super);
    function UniqueConstraint(name, columns, onConflict) {
        if (columns === void 0) { columns = []; }
        if (onConflict === void 0) { onConflict = sqliteModels.DefaultConstraintConflictResolution; }
        var _this = _super.call(this, name, columns) || this;
        _this.onConflict = onConflict;
        return _this;
    }
    UniqueConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (!typeChecks.isSqliteConstraintConflictResolution(this.onConflict))
            summary.errorMessages.push("Invalid conflict resolution type");
        return summary;
    };
    return UniqueConstraint;
}(Constraint));
exports.UniqueConstraint = UniqueConstraint;
var CheckConstraint = (function (_super) {
    __extends(CheckConstraint, _super);
    function CheckConstraint(name, columns, checkExpression, onConflict) {
        if (columns === void 0) { columns = []; }
        if (checkExpression === void 0) { checkExpression = null; }
        if (onConflict === void 0) { onConflict = sqliteModels.DefaultConstraintConflictResolution; }
        var _this = _super.call(this, name, columns) || this;
        _this.checkExpression = checkExpression;
        _this.onConflict = onConflict;
        return _this;
    }
    CheckConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (!typeChecks.isSqliteConstraintConflictResolution(this.onConflict))
            summary.errorMessages.push("Invalid conflict resolution type");
        if (helperFunctions.isNullOrWhitespace(this.checkExpression))
            summary.errorMessages.push("Check Expression cannot be NULL or whitespace");
        return summary;
    };
    return CheckConstraint;
}(Constraint));
exports.CheckConstraint = CheckConstraint;
var DefaultConstraint = (function (_super) {
    __extends(DefaultConstraint, _super);
    function DefaultConstraint(name, columns, value, onConflict) {
        if (columns === void 0) { columns = []; }
        if (value === void 0) { value = null; }
        if (onConflict === void 0) { onConflict = sqliteModels.DefaultConstraintConflictResolution; }
        var _this = _super.call(this, name, columns) || this;
        _this.value = value;
        _this.onConflict = onConflict;
        return _this;
    }
    DefaultConstraint.prototype.validate = function () {
        var summary = _super.prototype.validate.call(this);
        if (!typeChecks.isSqliteConstraintConflictResolution(this.onConflict))
            summary.errorMessages.push("Invalid conflict resolution type");
        return summary;
    };
    return DefaultConstraint;
}(Constraint));
exports.DefaultConstraint = DefaultConstraint;
