"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var helperObjects = require("../../helpers/objects");
var helperFunctions = require("../../helpers/functions");
var typeChecker = require("../../services/typeCheck.service");
var Trigger = (function () {
    function Trigger(name, when, event, eventColumns, condition, executeStatements) {
        if (when === void 0) { when = null; }
        if (event === void 0) { event = null; }
        if (eventColumns === void 0) { eventColumns = []; }
        if (condition === void 0) { condition = null; }
        if (executeStatements === void 0) { executeStatements = []; }
        this.name = name;
        this.when = when;
        this.event = event;
        this.eventColumns = eventColumns;
        this.condition = condition;
        this.executeStatements = executeStatements;
    }
    Trigger.prototype.validate = function () {
        var summary = new helperObjects.Summary();
        if (helperFunctions.isNullOrWhitespace(this.name))
            summary.errorMessages.push("Name cannot be NULL or whitespace");
        if (!typeChecker.isSqliteTriggerTime(this.when))
            summary.errorMessages.push("Invalid execution time: " + this.when);
        if (!typeChecker.isSqliteTriggerEvent(this.event))
            summary.errorMessages.push("Invalid execution event: " + this.event);
        var statementsCopy = (this.executeStatements || []).map(function (statement) {
            if (!helperFunctions.isNullOrWhitespace(statement))
                return statement;
        });
        if (!statementsCopy.length)
            summary.errorMessages.push("Triggers must have at least one statement to execute");
        return summary;
    };
    return Trigger;
}());
exports.Trigger = Trigger;
