"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = Object.setPrototypeOf ||
        ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
        function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var entity_abstract_1 = require("./entity.abstract");
var subEntities = require("./subDbEntities/subDbEntities.grouping");
var helperObjects = require("../helpers/objects");
var converters = require("../services/dataConversion.service");
var Table = (function (_super) {
    __extends(Table, _super);
    function Table(name, database, entity) {
        if (entity === void 0) { entity = null; }
        return _super.call(this, name, database, entity) || this;
    }
    Table.prototype.parseCreate = function (create) {
        var summary = new helperObjects.Summary();
        this.clear();
        return summary;
    };
    Table.prototype.parseJSON = function (object) {
        var summary = new helperObjects.Summary();
        this.clear();
        this.name = object.name;
        this.database = object.database;
        /* Columns */
        if (object.columns instanceof Array) {
            try {
                this.columns = object.columns.map(function (fileColumn) {
                    return new subEntities.Column(fileColumn.name, fileColumn.type);
                });
            }
            catch (e) {
                summary.append(this.onParseError(e, "column", "table"));
            }
        }
        else
            this.columns = [];
        /* Constraints */
        if (object.constraints instanceof Array) {
            try {
                this.constraints = object.constraints.map(function (fileConstraint) {
                    return converters.FileToEntity.TableConstraint(fileConstraint);
                });
            }
            catch (e) {
                summary.append(this.onParseError(e, "constraint", "table"));
            }
        }
        else
            this.constraints = [];
        /* Triggers */
        if (object.triggers instanceof Array) {
            try {
                this.triggers = object.triggers.map(function (fileTrigger) {
                    return new subEntities.Trigger(fileTrigger.name, fileTrigger.when, fileTrigger.event, fileTrigger.eventColumns, fileTrigger.condition, fileTrigger.executeStatements);
                });
            }
            catch (e) {
                summary.append(this.onParseError(e, "trigger", "table"));
            }
        }
        else
            this.triggers = [];
        return summary;
    };
    Table.prototype.clear = function () {
        this.columns = [];
        this.constraints = [];
        this.triggers = [];
        return this;
    };
    Table.prototype.asCreate = function () {
        return null;
    };
    Table.prototype.asJSON = function () {
        return {
            name: this.name,
            database: this.database,
            columns: (this.columns || []).map(function (column) {
                return {
                    name: column.name,
                    type: column.type
                };
            }),
            constraints: (this.constraints || []).map(function (constraint) {
                return converters.EntityToFile.TableConstraint(constraint);
            }),
            triggers: (this.triggers || []).map(function (trigger) {
                return {
                    name: trigger.name,
                    when: trigger.when,
                    event: trigger.event,
                    eventColumns: trigger.eventColumns,
                    condition: trigger.condition,
                    executeStatements: trigger.executeStatements
                };
            })
        };
    };
    return Table;
}(entity_abstract_1.Entity));
exports.Table = Table;
