"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var helperFunctions = require("../helpers/functions");
var helperObjects = require("../helpers/objects");
var dataStore_service_1 = require("../services/dataStore.service");
function read(files) {
    var result = new helperObjects.ResultSummary([]);
    files.forEach(function (filePath) {
        try {
            var contents = fs.readFileSync(filePath, dataStore_service_1.Memory.config.fileEncoding);
            result.data.push(contents);
        }
        catch (e) {
            result.summary.errorMessages.push("Could not read " + filePath + ": " + e.message);
        }
    });
    return result;
}
exports.read = read;
function find(searchPath, recursive, fileType, fileNameRegex) {
    if (recursive === void 0) { recursive = false; }
    if (fileType === void 0) { fileType = null; }
    if (fileNameRegex === void 0) { fileNameRegex = null; }
    /* Initialize values */
    var fileList;
    /* Get complete list of directory files */
    try {
        fileList = walk(searchPath, recursive);
    }
    catch (e) {
        throw new Error("Could not get contents of directory (" + searchPath + "): " + e.message);
    }
    /* Reduce by file type */
    if (!helperFunctions.isNullOrWhitespace(fileType)) {
        fileList = fileList.filter(function (file) {
            return file.toLowerCase().endsWith("." + fileType.toLowerCase());
        });
    }
    /* Reduce by files that meet RegEx search */
    if (!helperFunctions.isNullOrWhitespace(fileNameRegex)) {
        try {
            var regex = new RegExp(fileNameRegex);
            fileList = fileList.filter(function (file) {
                return regex.test(file);
            });
        }
        catch (e) {
            throw e;
        }
    }
    return fileList;
}
exports.find = find;
function walk(dir, recursive) {
    /* Ignore null directory input */
    if (helperFunctions.isNullOrWhitespace(dir))
        return [];
    /* Initialize list */
    var filesList = [];
    /* Get a list of directory contents & ensure an empty array if null returned */
    var directoryContents = fs.readdirSync(dir) || [];
    directoryContents.forEach(function (item) {
        /* Get the absolute path and stats of the item */
        var fullItem = path.resolve(dir, item);
        var itemStat = fs.statSync(fullItem);
        /* Handle item based on type */
        if (itemStat.isFile())
            filesList.push(fullItem);
        else if (itemStat.isDirectory() && recursive)
            /* Will recursively call when directory found and if requested */
            filesList = filesList.concat(walk(fullItem, recursive));
        /* not handling sym-links at the mo' */
    });
    return filesList;
}
