"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var helperObjects = require("../helpers/objects");
var dataStore_service_1 = require("../services/dataStore.service");
function write(jobs) {
    var summary = new helperObjects.Summary();
    jobs.forEach(function (job) {
        /* Check to make sure path exists, try to create it otherwise */
        if (!fs.existsSync(job.path)) {
            var walkSummary = walk(job.path);
            summary.append(walkSummary);
            /* Move to next file if path for this file cannot be created */
            if (walkSummary.errorMessages.length)
                return;
        }
        /* Write file */
        try {
            var fullFilePath = path.resolve(job.path, job.fileName);
            fs.writeFileSync(fullFilePath, job.contents, { encoding: dataStore_service_1.Memory.config.fileEncoding });
        }
        catch (e) {
            summary.errorMessages.push("Could not write " + fullFilePath + ": " + e.message);
        }
    });
    return summary;
}
exports.write = write;
function walk(targetDir) {
    var summary = new helperObjects.Summary();
    var sep = path.sep;
    var initDir = path.isAbsolute(targetDir) ? sep : '';
    try {
        targetDir
            .split(sep)
            .reduce(function (parentDir, childDir) {
            var curDir = path.resolve(parentDir, childDir);
            if (!fs.existsSync(curDir)) {
                fs.mkdirSync(curDir);
            }
            return curDir;
        }, initDir);
    }
    catch (e) {
        summary.errorMessages.push("Could not create path " + targetDir + ": " + e.message);
    }
    return summary;
}
