import * as sqliteModels from "./sqlite.models";
export declare namespace TableFile {
    /** Represents the entire table file */
    interface ITable {
        name: string;
        database: string;
        columns: IColumn[];
        constraints?: IConstraint[];
        triggers?: ITrigger[];
    }
    /** Column record */
    interface IColumn {
        name: string;
        type: sqliteModels.SqliteData;
    }
    /** Generic constraint record */
    interface IConstraint {
        name: string;
        type: sqliteModels.Constraint;
        columns: string[];
    }
    namespace ConstraintTypes {
        type constraintConflictResolution = sqliteModels.ConstraintConflictResolution;
        interface IPKConstraint extends IConstraint {
            onConflict?: constraintConflictResolution;
            order?: sqliteModels.Order;
            autoIncrement?: boolean;
        }
        interface IFKConstraint extends IConstraint {
            parentTable: string;
            parentColumn: string;
        }
        interface INotNullConstraint extends IConstraint {
            onConflict?: constraintConflictResolution;
        }
        interface IUniqueConstraint extends IConstraint {
            onConflict?: constraintConflictResolution;
        }
        interface ICheckConstraint extends IConstraint {
            expression: string;
            onConflict?: constraintConflictResolution;
        }
        interface IDefaultConstraint extends IConstraint {
            value: string | number;
            onConflict?: constraintConflictResolution;
        }
    }
    /** Generic trigger record */
    interface ITrigger {
        name: string;
        when: sqliteModels.TriggerTime;
        event: sqliteModels.TriggerEvent;
        eventColumns?: string[];
        condition?: string;
        executeStatements: string[];
    }
}
export declare namespace ViewFile {
    interface IView {
    }
}
export declare type SchemaEntityTypes = TableFile.ITable | ViewFile.IView;
