"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var subDbEntities = require("../dbEntities/subDbEntities/subDbEntities.grouping");
/**
 * Functions for converting schema-file objects into Entity/SubEntity objects used within this project.
 */
var FileToEntity;
(function (FileToEntity) {
    /**
     * Converts a schema-file constraint into a constraint object usable by the Table class.
     * @param constraint A schema-file constraint
     * @throws {TypeError}
     */
    function TableConstraint(constraint) {
        /* Let null conversions fail silently */
        if (!constraint)
            return null;
        /* Null types, on the other hand, are an issue */
        if (!constraint.type)
            throw new TypeError("Constraints must have a type.");
        /* Determine constraint type so we can create an object */
        switch (constraint.type.toLowerCase()) {
            case "pk":
                return new subDbEntities.PKConstraint(constraint.name, constraint.columns, constraint.autoIncrement, constraint.order, constraint.onConflict);
            case "fk":
                return new subDbEntities.FKConstraint(constraint.name, constraint.columns, constraint.parentTable, constraint.parentColumn);
            case "notnull":
                return new subDbEntities.NotNullConstraint(constraint.name, constraint.columns, constraint.onConflict);
            case "unique":
                return new subDbEntities.UniqueConstraint(constraint.name, constraint.columns, constraint.onConflict);
            case "check":
                return new subDbEntities.CheckConstraint(constraint.name, constraint.columns, constraint.expression, constraint.onConflict);
            case "default":
                return new subDbEntities.DefaultConstraint(constraint.name, constraint.columns, constraint.value, constraint.onConflict);
            default:
                throw new TypeError("Invalid constraint type: " + constraint.type);
        }
    }
    FileToEntity.TableConstraint = TableConstraint;
})(FileToEntity = exports.FileToEntity || (exports.FileToEntity = {}));
var EntityToFile;
(function (EntityToFile) {
    function TableConstraint(constraint) {
        var fileConstraint = {
            name: constraint.name,
            columns: constraint.columns || [],
            type: null
        };
        /* Let null conversions fail silently */
        if (!constraint)
            return null;
        if (constraint instanceof subDbEntities.PKConstraint) {
            fileConstraint.type = "pk";
            fileConstraint.autoIncrement = constraint.autoIncrement;
            fileConstraint.onConflict = constraint.onConflict;
            fileConstraint.order = constraint.order;
        }
        else if (constraint instanceof subDbEntities.FKConstraint) {
            fileConstraint.type = "fk";
            fileConstraint.parentColumn = constraint.parentColumn;
            fileConstraint.parentTable = constraint.parentTable;
        }
        else if (constraint instanceof subDbEntities.NotNullConstraint) {
            fileConstraint.type = "notnull";
            fileConstraint.onConflict = constraint.onConflict;
        }
        else if (constraint instanceof subDbEntities.UniqueConstraint) {
            fileConstraint.type = "unique";
            fileConstraint.onConflict = constraint.onConflict;
        }
        else if (constraint instanceof subDbEntities.CheckConstraint) {
            fileConstraint.type = "check";
            fileConstraint.expression = constraint.checkExpression;
            fileConstraint.onConflict = constraint.onConflict;
        }
        else if (constraint instanceof subDbEntities.DefaultConstraint) {
            fileConstraint.type = "default";
            fileConstraint.value = constraint.value;
            fileConstraint.onConflict = constraint.onConflict;
        }
        else {
            throw new TypeError("Invalid constraint type");
        }
        return fileConstraint;
    }
    EntityToFile.TableConstraint = TableConstraint;
})(EntityToFile = exports.EntityToFile || (exports.EntityToFile = {}));
