"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var clArgs = require("command-line-args");
var clCommands = require("command-line-commands");
var constants = require("./services/dataConstants.service");
var fsio = require("./fsio/fsio.grouping");
var path = require("path");
var fs = require("fs");
var dataStore_service_1 = require("./services/dataStore.service");
var helperObjects = require("./helpers/objects");
var typeChecker = require("./services/typeCheck.service");
var table_1 = require("./dbEntities/table");
var dataModel = require("./services/dataModel.service");
var assert = require("assert");
var Typelite = (function () {
    function Typelite(cliMode) {
        if (cliMode === void 0) { cliMode = false; }
        /* Load some initial values into session storage */
        dataStore_service_1.Memory.cliMode = cliMode;
        try {
            /*
             * This one time, we are assuming the encoding of a file is UTF8.
             * That will be a noted requirement in the documentation.
             */
            dataStore_service_1.Memory.config = JSON.parse(fs.readFileSync(path.resolve(__dirname, "../typeliteconfig.json")).toString());
        }
        catch (e) {
            throw new Error("Could not load configuration file: " + e.message);
        }
    }
    // public deploy(entities: )
    Typelite.prototype.debug = function () {
        var results = new helperObjects.ResultSummary();
        results.data = [];
        var filesContents = fsio.read(fsio.find('../test', true, 'json', "read_.*"));
        var filesAsJSON = [];
        filesContents.data.forEach(function (content) {
            try {
                var obj = JSON.parse(content);
                filesAsJSON.push(obj);
            }
            catch (e) {
                results.summary.errorMessages.push(("Could not parse: " + content));
            }
        });
        filesAsJSON.forEach(function (obj) {
            try {
                if (typeChecker.isITable(obj)) {
                    var t = new table_1.Table(null, null, obj);
                    results.data.push(t);
                }
            }
            catch (e) {
                results.summary.errorMessages.push("Could not parse table: " + e.message);
            }
        });
        var writeJobs = results.data.map(function (table) {
            return dataModel.IFileWriteJobInstance([table.database || "", "table", table.name || "", "json"].join("."), "../test/schema/out/", JSON.stringify(table.asJSON()));
        });
        results.summary.append(fsio.write(writeJobs));
        var reloadedTables = fsio.read(fsio.find("../test/schema/out", false, "json"))
            .data.map(function (content) {
            return new table_1.Table(null, null, JSON.parse(content));
        });
        try {
            assert.deepEqual(reloadedTables, results.data, "Load results do not match.");
            results.summary.infoMessages.push("SUCCESS!");
        }
        catch (e) {
            results.summary.errorMessages.push(e.message);
        }
        console.log(results);
    };
    return Typelite;
}());
exports.Typelite = Typelite;
var CLI;
(function (CLI) {
    function deploy(params) {
    }
    CLI.deploy = deploy;
    function generate(params) {
    }
    CLI.generate = generate;
    function debug() {
        var typelite = new Typelite(true);
        typelite.debug();
    }
    CLI.debug = debug;
})(CLI || (CLI = {}));
/* CLI execution */
if (require.main === module) {
    /* Parse CLI */
    try {
        /* Get the typelite command and arguments */
        var _a = clCommands(constants.CLI.commands), command = _a.command, argv = _a.argv;
        /* Parse the CLI options that go with the current command */
        var args = clArgs(constants.CLI.options, { partial: true })[command];
        // console.log("command:   %s", command);
        // console.log("argv:      %s", JSON.stringify(argv));
        // console.log("args:      %s", JSON.stringify(args));
        switch (command) {
            case "deploy":
                CLI.deploy({
                    xml: args.xml,
                    clean: args.clean,
                    schema: args.schema,
                    databases: args.databases
                });
                break;
            case "generate":
                CLI.generate({});
                break;
            case "debug":
                CLI.debug();
                break;
        }
    }
    catch (e) {
        console.error(e.message);
    }
}
